# OSSPREY Python Client
Python client for scanning your code for Malware!

# Installing

Just run `pip install git+https://github.com/ossprey/ossprey-python-client` to install locally

Then you can run it with `python -m scan --help`

## Requirements

This package requires you are on python3.12 or above. Feel free to raise an issue if you need other support.
